#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# === This file is part of Calamares - <http://github.com/calamares> ===
#
#   Copyright 2017, Matthias Klumpp <mak@debian.org>
#
#   Calamares is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   Calamares is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with Calamares. If not, see <http://www.gnu.org/licenses/>.

import libcalamares
import os


def enable_gnome_initial_setup():
    """ Enables GNOME Initial Setup in GDM.

    :return:
    """
    root_mount_point = libcalamares.globalstorage.value("rootMountPoint")

    gdm_name = "gdm"
    gdm_etc_dir = os.path.join(root_mount_point, "etc", gdm_name)
    if not os.path.exists(gdm_etc_dir):
        gdm_name = "gdm3"
        gdm_etc_dir = os.path.join(root_mount_point, "etc", gdm_name)
        if not os.path.exists(gdm_etc_dir):
            raise Exception("GDM was not found!")

    gdmconf_snippet = os.path.join(gdm_etc_dir, "custom.conf")
    f = open(gdmconf_snippet, 'w')
    f.write("[daemon]\nInitialSetupEnable=True\n")
    f.close()

    initsetup_trigger = os.path.join(root_mount_point, "var", "lib", gdm_name, "run-initial-setup")
    f = open(initsetup_trigger, 'w')
    f.write("\n")
    f.close()


def run():
    """ Starts procedure

    :return:
    """
    enable_gnome_initial_setup()

    return None
